See doc/contribute.rst in this repository or its [html version](https://iminuit.readthedocs.io/en/latest/contribute.html).

The wheel building system comes from [scikit-hep/azure-wheel-helpers](https://github.com/scikit-hep/azure-wheel-helpers), see that first if you need to update the wheel build system (for a new Python version, for example).
